Project layout
===

Assumed project layout, when building images from docker-compose.yml with docker-compose build

```
*                // context root
|-backend
| |-account
| |-address
| |-auth
| |-cardpayment
| |-common
| |-contract
| |-document
| |-extras
| |-gateway      // you are here
| |-geo
| |-identity
| |-invitation
| |-maintenance
| |-messaging
| |-notification 
| |-oauth
| |-offer
| |-property
| |-query-parser
| |-twilio
| |-verification
| |-zeebe
|-devops         // extra
|-frontend       // extra
```

Adding extra directories (if any) in context root to .dockerignore might be beneficial to build times

Replace directives
===

When implementing a task requiring changes in multiple repositories, including API changes, you would need to have changes in one repository to reflect in many others.

In that case, [go.mod replace directive](https://golang.org/ref/mod#tmp_14) might be used.

Say, you have made some changes to geo API and want property service to account for them in your local build.

Then you need go to backend/property/go.mod, add

```
replace gitlab.okta-solutions.com/mashroom/backend/geo/api => ../geo/api
```

rebuild propety service using

```
docker-compose build mashroom-property
```

and start new version of property serivce


```
docker-compose up -d mashroom-property
```

Openvpn docker network exposure
===

When developing on macos or windows, local docker implementation prevents you from directly accessing docker network bridge.

To workaround that, openvpn may be added to the compose deployment, instead of invoking e.g.

```
docker-compose -f docker-compose.yml up -d
```

you would need to do

```
docker-compose -f docker-compose.yml -f docker-compose.ovpn.yml up -d
```

or use gateway's Makefile targets `dev-ovpn-up`, `dev-ovpn-down` and `dev-ovpn-stop` to simplify that

and then you can connect to VPN using https://github.com/fardjad/docker-network-exposer/blob/master/README.md guide

Debugging
===

To run specific docker-compose service in dlv debug mode, using local filesystem mounted inside container with local replaces


```
./debug.sh property
./debug.sh offer
./debug.sh gateway
```

To build debug docker image using local replaces


```
./build-debug-image.sh property
./build-debug-image.sh offer
./build-debug-image.sh gateway
```
