#!/bin/bash
SVC="$1"

[ -d "../$SVC" ] || { echo "USAGE: $0 svcname"; exit 1; }

echo "launching $SVC in debug mode"

tmp="$(mktemp)"

trap "rm $tmp" INT QUIT TERM EXIT

cat > $tmp <<EOF
FROM registry.gitlab.okta-solutions.com/mashroom/backend/common/gobuild:1.14.3 as builder
COPY . /go/src/gitlab.okta-solutions.com/mashroom
WORKDIR /go/src/gitlab.okta-solutions.com/mashroom/backend/$SVC
RUN export GO111MODULE=on CGO_ENABLED=0 GOOS=linux GOARCH=amd64 GOPRIVATE=gitlab.okta-solutions.com && \\
    go mod download && \\
    go generate -v tools.go && \\
    go generate -v && \\
    go build -tags netgo -ldflags '-w -extldflags "-static"' -v ./cmd/... && \\
    go install -tags netgo -ldflags '-w -extldflags "-static"' -v github.com/go-delve/delve/cmd/dlv
ENTRYPOINT ["/go/bin/dlv", "debug", "--headless", "--listen=:2345", "--api-version=2", "--continue", "--accept-multiclient", "--log", "./cmd/mashroom-$SVC"]
EOF

pwd

docker build -t "registry.gitlab.okta-solutions.com/mashroom/backend/${SVC}:debug" -f $tmp ../..
