package impl

import (
	"bytes"
	"compress/gzip"
	"fmt"
	"io"
	"strings"
)

func bindata_read(data []byte, name string) ([]byte, error) {
	gz, err := gzip.NewReader(bytes.NewBuffer(data))
	if err != nil {
		return nil, fmt.Errorf("Read %q: %v", name, err)
	}

	var buf bytes.Buffer
	_, err = io.Copy(&buf, gz)
	gz.Close()

	if err != nil {
		return nil, fmt.Errorf("Read %q: %v", name, err)
	}

	return buf.Bytes(), nil
}

var _playground_html = []byte("\x1f\x8b\x08\x00\x00\x00\x00\x00\x00\xff\xac\x54\xc1\x8e\xe3\x36\x0c\xbd\xe7\x2b\x58\xf7\xe0\x0c\x36\xb1\x76\xdb\x43\x0b\x8f\x9d\x16\x6d\x07\xc5\x02\x0b\xec\x14\xed\xa5\x47\x45\xa2\x63\xcd\xca\x94\x57\xa4\x93\x09\x0c\xff\x7b\xa1\x38\x99\xc9\x74\xf7\xb0\x87\xd1\x45\x14\x29\xbe\x47\x52\xa4\xaa\xef\xfe\xf8\xf8\xfb\x3f\xff\xde\xdf\x41\x2b\x9d\xdf\x2c\xaa\xcb\x86\xda\x6e\x16\x00\x00\x55\x87\xa2\xc1\xb4\x3a\x32\x4a\x3d\x48\xb3\xfe\x59\x5d\x5b\x48\x77\x58\x67\x7b\x87\x87\x3e\x44\xc9\xc0\x04\x12\x24\xa9\xb3\x81\x31\xae\xd9\x68\xaf\xb7\x1e\x6b\x0a\x2b\x70\xe4\xc4\x69\x7f\x52\x62\xfd\xae\x78\xbb\x82\xce\x91\xeb\x86\xee\x85\x4a\x3f\x7e\xa1\x4a\xb7\xb4\x5f\x0f\x2e\x3b\x53\x7b\x47\x9f\x20\xa2\xaf\x33\x6e\x43\x14\x33\x08\x38\x13\x28\x83\x36\x62\x53\x67\xad\x48\xcf\xa5\x52\xbb\xa8\xfb\xd6\x84\xe0\xd7\xbd\xd7\xc7\x5d\x0c\x03\xd9\x82\x50\xbc\x6b\x8e\x85\x09\x9d\x6a\xf4\x3e\xf9\x15\x3d\xed\xbe\x02\x2d\x47\x8f\xdc\x22\xca\x05\x57\x29\x63\xa9\x78\x60\x8b\xde\xed\x63\x42\x52\xd4\x77\x33\xcd\xe7\x6b\x92\x75\x44\x6d\xe4\xd7\x71\x84\x62\x8f\x91\x5d\x20\x98\x26\xb5\x1d\x9c\xb7\x8a\x45\x8b\x33\xca\x30\x2b\x47\x16\x1f\x0b\xc3\x9c\xa9\x6f\x4b\xec\x55\x02\xb8\x4e\xfa\xc2\xcb\x26\xba\x5e\x80\xa3\x79\xdd\x2c\x1f\x58\x75\xce\x5a\x8f\x07\x1d\xb1\x78\xe0\x6c\x53\xa9\x99\xeb\x4c\x2c\x4e\x3c\x6e\xc6\xb1\x38\x09\xd3\x54\xa9\x59\xb3\xa8\xd4\xdc\x84\xd5\x36\xd8\xe3\x66\x51\x9d\x5e\x03\xe4\xd8\x63\x9d\x09\x3e\x4a\x2a\xe0\xf9\xcd\x52\xd3\xc2\x08\x4d\x20\x59\x37\xba\x73\xfe\x58\x42\xf6\xb1\x47\x82\xbf\x35\x71\xb6\x02\xd6\xc4\x6b\xc6\xe8\x9a\x5b\x08\x7b\x8c\x8d\x0f\x87\x12\x5a\x67\x2d\xd2\x2d\x4c\x27\x90\x44\x03\x23\x74\x3a\xee\x1c\x95\xf0\xf6\x16\xb6\xda\x7c\x9a\x13\x2d\xe1\xfb\x77\x3f\xfd\xa0\x7f\xd4\xe9\x72\xa5\x4e\xa1\x6c\x16\x95\x75\x7b\x70\xb6\xce\x62\x08\x92\x2a\x79\xa9\xe2\x55\x90\x0f\x7a\xaf\x67\xed\x39\xd6\x83\x23\x1b\x0e\x85\xb6\xf6\x6e\x8f\x24\x1f\x1c\x0b\x12\xc6\x65\xee\x83\xb6\xf9\x0a\x9a\x81\x8c\xa4\x4a\x2e\x31\xd9\x6f\x60\x3c\xb9\xa5\x65\x02\xb1\x40\x22\x83\x1a\x6c\x30\x43\x87\x24\xc5\x0e\xe5\xce\x63\x12\x7f\x3b\xbe\xb7\xcb\x3c\xd9\xf3\x9b\xdb\x27\xaf\x74\x2e\x8c\xd7\xcc\x89\x2b\x11\x2f\xf3\xe7\x27\x7c\x4f\xd7\x77\x67\x86\x03\xdf\xc7\x20\x01\x6a\xf0\xc1\xe8\x14\x4c\xd1\x27\x85\x09\x1e\xea\x1a\xf2\x79\xba\x72\xf8\x05\xf2\x03\x27\xa1\x4c\x42\x99\x3f\xc1\xfc\x99\x3a\xe5\xaf\x0f\xf7\xcf\x33\x97\x46\x7f\x99\x22\x59\x5d\xe5\x93\x16\x92\xed\x83\x23\x29\xbf\xc2\xf5\x06\x72\xa5\x72\x78\xf3\x6c\x6a\x03\x4b\x52\x8f\x63\x71\x71\x9c\xa6\x7c\xf5\x02\x91\x87\xed\x5c\x70\x17\x88\xef\x9e\xe0\x2f\x49\x7d\x13\x28\x7c\x89\x8a\x22\x8e\x76\x5c\xfe\x2f\xfe\xb4\xf2\x88\x9f\x07\x64\x29\x4c\x44\x8b\x94\xfe\x38\xce\x4b\xc8\x59\x77\xb8\x0e\xd1\xed\x1c\xe5\x2f\x9c\xa6\xa7\xd3\x74\xb3\x38\x6f\xcf\x63\x51\xa9\x73\xc7\xab\xd3\x67\xfc\x5f\x00\x00\x00\xff\xff\x91\x2f\x53\x65\xa3\x05\x00\x00")

func playground_html() ([]byte, error) {
	return bindata_read(
		_playground_html,
		"playground.html",
	)
}

// Asset loads and returns the asset for the given name.
// It returns an error if the asset could not be found or
// could not be loaded.
func Asset(name string) ([]byte, error) {
	cannonicalName := strings.Replace(name, "\\", "/", -1)
	if f, ok := _bindata[cannonicalName]; ok {
		return f()
	}
	return nil, fmt.Errorf("Asset %s not found", name)
}

// AssetNames returns the names of the assets.
func AssetNames() []string {
	names := make([]string, 0, len(_bindata))
	for name := range _bindata {
		names = append(names, name)
	}
	return names
}

// _bindata is a table, holding each asset generator, mapped to its name.
var _bindata = map[string]func() ([]byte, error){
	"playground.html": playground_html,
}

// AssetDir returns the file names below a certain
// directory embedded in the file by go-bindata.
// For example if you run go-bindata on data/... and data contains the
// following hierarchy:
//     data/
//       foo.txt
//       img/
//         a.png
//         b.png
// then AssetDir("data") would return []string{"foo.txt", "img"}
// AssetDir("data/img") would return []string{"a.png", "b.png"}
// AssetDir("foo.txt") and AssetDir("notexist") would return an error
// AssetDir("") will return []string{"data"}.
func AssetDir(name string) ([]string, error) {
	node := _bintree
	if len(name) != 0 {
		cannonicalName := strings.Replace(name, "\\", "/", -1)
		pathList := strings.Split(cannonicalName, "/")
		for _, p := range pathList {
			node = node.Children[p]
			if node == nil {
				return nil, fmt.Errorf("Asset %s not found", name)
			}
		}
	}
	if node.Func != nil {
		return nil, fmt.Errorf("Asset %s not found", name)
	}
	rv := make([]string, 0, len(node.Children))
	for name := range node.Children {
		rv = append(rv, name)
	}
	return rv, nil
}

type _bintree_t struct {
	Func     func() ([]byte, error)
	Children map[string]*_bintree_t
}

var _bintree = &_bintree_t{nil, map[string]*_bintree_t{
	"playground.html": &_bintree_t{playground_html, map[string]*_bintree_t{}},
}}
