package resolvers

import (
	"github.com/graphql-go/graphql"
	address "gitlab.okta-solutions.com/mashroom/backend/address/api"
	"gitlab.okta-solutions.com/mashroom/backend/common/graphql/util"
	"gitlab.okta-solutions.com/mashroom/backend/gateway/impl/connections"
)

func initAddress(rootQueries, rootMutations *graphql.Fields) {
	query := graphql.NewObject(graphql.ObjectConfig{
		Name:        "AddressQuery",
		Description: "Address query root",
		Fields: graphql.Fields{
			"postcode": &graphql.Field{
				Description: "Get addresses by postcode",
				Args:        util.BindArguments(address.PostcodeRequest{}),
				Resolve:     AddressPostcodeResolver,
				Type:        util.BindOutput(address.AddressesResponse{}, "Addresses array", nil),
			},
			"query": &graphql.Field{
				Description: "Get addresses by query ",
				Args:        util.BindArguments(address.QueryRequest{}),
				Resolve:     AddressQueryResolver,
				Type:        util.BindOutput(address.AddressesResponse{}, "Addresses array", nil),
			},
		},
	})

	(*rootQueries)["address"] = &graphql.Field{
		Type: query,
		Resolve: func(p graphql.ResolveParams) (interface{}, error) {
			return query, nil
		},
	}
}

func AddressPostcodeResolver(params graphql.ResolveParams) (interface{}, error) {
	request := &address.PostcodeRequest{}
	if err := util.UnmarshalArguments(params.Args, request); err != nil {
		return nil, err
	}
	return connections.AddressService.GetAddressesByPostcode(params.Context, request)
}

func AddressQueryResolver(params graphql.ResolveParams) (interface{}, error) {
	request := &address.QueryRequest{}
	if err := util.UnmarshalArguments(params.Args, request); err != nil {
		return nil, err
	}
	return connections.AddressService.GetAddressesByQuery(params.Context, request)
}
