package admin

import (
	"github.com/graphql-go/graphql"
	"gitlab.okta-solutions.com/mashroom/backend/common/graphql/util"
	contract "gitlab.okta-solutions.com/mashroom/backend/contract/api"
	"gitlab.okta-solutions.com/mashroom/backend/gateway/impl/connections"
	"gitlab.okta-solutions.com/mashroom/backend/gateway/impl/resolvers"
)

func initContract(query, mutation *graphql.Fields) {
	(*query)["ContractHistory"] = &graphql.Field{
		Description: "Returns history of given contract at given depth",
		Args:        util.BindArguments(contract.HistoryRequest{}),
		Resolve:     ContractQueryHistoryResolver,
		Type:        util.BindOutput(contract.HistoryResponse{}, "Revisions list", nil),
	}
	(*query)["allContracts"] = &graphql.Field{
		Description: "Returns list of children contracts",
		Args:        util.BindArguments(contract.ListRequest{}),
		Resolve:     ContractQueryListResolver,
		Type:        util.BindOutput(contract.ListResponse{}, "Contracts list", nil),
	}
}

func ContractQueryHistoryResolver(params graphql.ResolveParams) (interface{}, error) {
	if err := resolvers.CheckPermissions(params.Context, resolvers.AdminRole); err != nil {
		return nil, err
	}
	request := &contract.HistoryRequest{}
	if err := util.UnmarshalArguments(params.Args, request); err != nil {
		return nil, err
	}
	return connections.ContractService.History(params.Context, request)
}

func ContractQueryListResolver(params graphql.ResolveParams) (interface{}, error) {
	if err := resolvers.CheckPermissions(params.Context, resolvers.AdminRole); err != nil {
		return nil, err
	}
	request := &contract.ListRequest{}
	if err := util.UnmarshalArguments(params.Args, request); err != nil {
		return nil, err
	}
	return connections.ContractService.List(params.Context, request)
}
