package admin

import (
	"github.com/graphql-go/graphql"
	q "gitlab.okta-solutions.com/mashroom/backend/common/api/generic/query"
	"gitlab.okta-solutions.com/mashroom/backend/common/graphql/util"
	"gitlab.okta-solutions.com/mashroom/backend/gateway/impl/connections"
	"gitlab.okta-solutions.com/mashroom/backend/gateway/impl/resolvers"
	maintenance "gitlab.okta-solutions.com/mashroom/backend/maintenance/api"
)

type allMaintenancesResult struct {
	Data  []*maintenance.Maintenance `json:"data,omitempty"`
	Total int32                      `json:"total,omitempty"`
}

func initMaintenance(query, _ *graphql.Fields) {
	(*query)["allMaintenances"] = &graphql.Field{
		Description: "Retrieves maintenance filtered list",
		Args:        util.BindArguments(allParams{}),
		Resolve:     adminQueryAllMaintenanceResolver,
		Type:        util.BindOutput(allMaintenancesResult{}, "Property list", nil),
	}
}

func adminQueryAllMaintenanceResolver(params graphql.ResolveParams) (interface{}, error) {
	if err := resolvers.CheckPermissions(params.Context, resolvers.AdminRole); err != nil {
		return nil, err
	}
	input := &allParams{}
	if err := util.UnmarshalArguments(params.Args, input); err != nil {
		return nil, err
	}
	req := &q.QueryParams{
		Filter: input.Filter,
		Sort:   input.Sort,
		Pagination: &q.QueryParamsPagination{
			Page:    input.Pagination.Page,
			PerPage: input.Pagination.PerPage,
		},
	}
	if input.Sort == nil {
		req.Sort = []*q.QueryParamsSort{{Field: "created_at", Order: -1}}
	}
	request := &maintenance.ListFilterRequest{
		Params:    req,
		AdminSite: true,
	}
	request.AdminSite = true
	resp, err := connections.MaintenanceService.ListFilter(params.Context, request)
	if err != nil {
		return nil, err
	}
	ms := resp.GetMaintenances()
	total := resp.GetTotal()
	return allMaintenancesResult{
		Data:  ms,
		Total: total,
	}, nil
}
