package admin

import (
	"github.com/graphql-go/graphql"
	auth "gitlab.okta-solutions.com/mashroom/backend/auth/api"
	"gitlab.okta-solutions.com/mashroom/backend/common/graphql/util"
	ws "gitlab.okta-solutions.com/mashroom/backend/common/graphql/websocket"
	"gitlab.okta-solutions.com/mashroom/backend/gateway/impl/connections"
	"gitlab.okta-solutions.com/mashroom/backend/gateway/impl/resolvers"
	rightmove "gitlab.okta-solutions.com/mashroom/backend/rightmove/api"
)

func initRightmove(query, mutation *graphql.Fields) {
	(*mutation)["publishRightmove"] = &graphql.Field{
		Description: "Publish property on Rightmove",
		Args:        util.BindArguments(getParams{}),
		Resolve:     RightmovePublishResolver,
		Type:        util.BindOutput(rightmove.SendPropertyResponse{}, "Property ids", nil),
	}
	(*mutation)["deleteRightmove"] = &graphql.Field{
		Description: "Delete published property from Rightmove",
		Args:        util.BindArguments(getParams{}),
		Resolve:     RightmoveDeleteResolver,
		Type:        util.BindOutput(rightmove.DeletePropertyResponse{}, "Delete result", nil),
	}
}

func RightmovePublishResolver(params graphql.ResolveParams) (interface{}, error) {
	if err := resolvers.CheckPermissions(params.Context, resolvers.AdminRole); err != nil {
		return nil, err
	}
	req := &getParams{}
	if err := util.UnmarshalArguments(params.Args, req); err != nil {
		return nil, err
	}
	user := params.Context.Value(ws.CtxUser).(*auth.AuthResponse)
	request := &rightmove.PropertyRequest{
		PropertyId: req.ID,
		User:       user.GetAccount().GetIdValue(),
	}
	resp, err := connections.RightmoveService.SendProperty(params.Context, request)
	if err != nil {
		return nil, err
	}
	if (resp.GetRightmoveId() == "") || (resp.GetRightmoveId() == "0") || (resp.GetRightmoveUrl() == "") {
		resp.Success = false
	}
	return resp, nil
}

func RightmoveDeleteResolver(params graphql.ResolveParams) (interface{}, error) {
	if err := resolvers.CheckPermissions(params.Context, resolvers.AdminRole); err != nil {
		return nil, err
	}
	req := &getParams{}
	if err := util.UnmarshalArguments(params.Args, req); err != nil {
		return nil, err
	}
	user := params.Context.Value(ws.CtxUser).(*auth.AuthResponse)
	request := &rightmove.PropertyRequest{
		PropertyId: req.ID,
		User:       user.GetAccount().GetIdValue(),
	}
	return connections.RightmoveService.DeleteProperty(params.Context, request)
}
