package admin

import (
	"github.com/graphql-go/graphql"
	"gitlab.okta-solutions.com/mashroom/backend/common/graphql/util"
	"gitlab.okta-solutions.com/mashroom/backend/gateway/impl/connections"
	"gitlab.okta-solutions.com/mashroom/backend/gateway/impl/resolvers"
	signature "gitlab.okta-solutions.com/mashroom/backend/signature/api"
)

func initSignature(query, mutation *graphql.Fields) {
	(*mutation)["adminSignature"] = &graphql.Field{
		Description: "Update signature state",
		Args:        util.BindArguments(signature.AdminRequest{}),
		Resolve:     SignatureAdminResolver,
		Type:        util.BindOutput(signature.AdminResponse{}, "Signature update result", nil),
	}
}

func SignatureAdminResolver(params graphql.ResolveParams) (interface{}, error) {
	if err := resolvers.CheckPermissions(params.Context, resolvers.AdminRole); err != nil {
		return nil, err
	}
	request := &signature.AdminRequest{}
	if err := util.UnmarshalArguments(params.Args, request); err != nil {
		return nil, err
	}
	resp, err := connections.SignatureService.HandleAdmin(params.Context, request)
	if err != nil {
		return nil, err
	}
	return resp, err
}
