package resolvers

import (
	"bytes"
	"compress/gzip"
	"fmt"
	"io"
	"strings"
)

func bindata_read(data []byte, name string) ([]byte, error) {
	gz, err := gzip.NewReader(bytes.NewBuffer(data))
	if err != nil {
		return nil, fmt.Errorf("Read %q: %v", name, err)
	}

	var buf bytes.Buffer
	_, err = io.Copy(&buf, gz)
	gz.Close()

	if err != nil {
		return nil, fmt.Errorf("Read %q: %v", name, err)
	}

	return buf.Bytes(), nil
}

var _ipsum_txt = []byte("\x1f\x8b\x08\x00\x00\x00\x00\x00\x00\xff\x4c\x92\x4d\x6a\x64\x39\x10\x84\xaf\x12\x07\x78\xbc\x3b\x0c\x36\x03\xde\x0c\x1e\x98\x69\xe8\x65\x96\x94\x55\x4e\x5b\x7f\xce\x9f\x67\x7a\xe7\x6b\xf8\x7a\x3e\x49\x23\xb9\x5c\xf4\x46\x20\x48\x32\x23\xbe\x88\x9f\xbd\x74\xc8\xb0\xa8\xc8\xbd\x74\x85\x89\x83\x2a\xfb\x86\xd4\x9b\x71\x72\xf6\x50\x50\x96\x21\x96\xa4\x5d\xc0\x45\x7c\xc7\xff\x0e\x4a\xb0\xb0\x24\x43\x1c\x85\xfb\x8e\x3b\xd2\xc1\xc8\xc2\x15\x47\x94\x11\x4e\xce\x60\x73\x34\x4e\x48\xbd\xd6\x9e\x3b\x34\x5c\xa3\xee\x78\xe4\x52\xb8\x39\xdb\x6b\x30\x2a\xb9\x8b\xcd\x8b\x07\x95\x22\x86\x26\x26\xe0\x00\xb5\x8c\x07\x90\xb4\xcf\xf7\x0f\x87\x79\x1f\x43\x1a\xa2\xb9\x14\xf8\x13\xc3\xde\x98\x14\xcf\xa4\x9f\xef\x1f\x86\x73\x94\xb2\xa4\xe9\x53\x6f\x29\x0c\xc7\x14\x0b\x72\x54\x0a\x15\x83\x34\x67\xcd\x51\x37\x9c\x55\xda\x45\x4a\x21\x64\x49\x1e\x15\x8d\xa7\x90\x6f\x75\x77\xa1\x74\x92\xe9\xfc\x2a\xad\x67\xe9\x73\x11\x2b\x39\x0e\x39\x58\x95\x50\xfa\xa9\xab\x8b\xed\x78\x5c\xc2\x3e\xdf\x3f\x70\xea\xee\x85\x0d\xbd\x2d\x81\x92\x78\x83\xab\x98\xcb\xdc\x7f\x03\x76\x15\xc4\x85\x2b\xb7\x79\xdf\xb9\x8e\xb0\x1d\xff\x86\x2c\x24\xe1\x38\xf3\x44\x71\x88\x13\x2f\xea\x6b\xa6\xeb\xcd\xc5\x4d\x07\x4d\xca\x3b\xee\xb5\x0f\xcc\x30\xe4\x85\x21\xbe\x90\x3c\x75\xdf\xa6\xee\xa1\xec\x12\x15\xaf\x41\x75\xc7\x43\x5b\x99\x58\xe2\xc2\xfa\x75\x6f\x84\xce\xf3\xff\x50\x45\x96\x4b\x13\x33\xa9\x28\x34\x29\xae\x7a\x6c\x20\x44\x29\x54\x53\xd7\xc1\x8a\x36\x3f\xb7\xb5\xad\xb7\x1d\x7f\x15\x99\xeb\x61\x9c\xc1\x4d\x2a\xce\x14\x49\x4e\x61\x1b\x46\x94\x43\x1a\xe9\xd5\x13\xf9\xf6\x47\x45\x28\x2e\xc1\x3b\xfe\xe3\xb6\xc1\xd7\xf3\xc6\xcd\xe5\x06\xb1\xe2\x2c\xe7\xf9\x5f\x24\xd3\xcb\x32\xf4\xc5\x0b\x45\x4e\xac\x1d\x67\xd6\x2b\x47\xc9\x3b\x7e\xc8\x41\x35\x6c\x32\x5c\x45\xba\x19\x5a\xa5\xce\x72\x1d\x0d\x6d\x34\x2b\xb2\x7d\x77\xa0\x92\x19\xed\xb8\xef\x13\xce\x73\x98\x77\xfc\xea\xa5\x6f\xd7\x5a\x5c\xa3\xc8\x21\x90\xb6\x21\xd3\x98\xe6\xbe\x53\x71\x2e\x65\x12\x7c\x40\xee\x33\x85\x93\x5c\x76\xfc\x1d\x96\x56\x96\x46\x17\x59\x45\xaa\xb2\xff\x0e\x00\x00\xff\xff\x93\xe5\x31\x54\x74\x03\x00\x00")

func ipsum_txt() ([]byte, error) {
	return bindata_read(
		_ipsum_txt,
		"ipsum.txt",
	)
}

// Asset loads and returns the asset for the given name.
// It returns an error if the asset could not be found or
// could not be loaded.
func Asset(name string) ([]byte, error) {
	cannonicalName := strings.Replace(name, "\\", "/", -1)
	if f, ok := _bindata[cannonicalName]; ok {
		return f()
	}
	return nil, fmt.Errorf("Asset %s not found", name)
}

// AssetNames returns the names of the assets.
func AssetNames() []string {
	names := make([]string, 0, len(_bindata))
	for name := range _bindata {
		names = append(names, name)
	}
	return names
}

// _bindata is a table, holding each asset generator, mapped to its name.
var _bindata = map[string]func() ([]byte, error){
	"ipsum.txt": ipsum_txt,
}

// AssetDir returns the file names below a certain
// directory embedded in the file by go-bindata.
// For example if you run go-bindata on data/... and data contains the
// following hierarchy:
//     data/
//       foo.txt
//       img/
//         a.png
//         b.png
// then AssetDir("data") would return []string{"foo.txt", "img"}
// AssetDir("data/img") would return []string{"a.png", "b.png"}
// AssetDir("foo.txt") and AssetDir("notexist") would return an error
// AssetDir("") will return []string{"data"}.
func AssetDir(name string) ([]string, error) {
	node := _bintree
	if len(name) != 0 {
		cannonicalName := strings.Replace(name, "\\", "/", -1)
		pathList := strings.Split(cannonicalName, "/")
		for _, p := range pathList {
			node = node.Children[p]
			if node == nil {
				return nil, fmt.Errorf("Asset %s not found", name)
			}
		}
	}
	if node.Func != nil {
		return nil, fmt.Errorf("Asset %s not found", name)
	}
	rv := make([]string, 0, len(node.Children))
	for name := range node.Children {
		rv = append(rv, name)
	}
	return rv, nil
}

type _bintree_t struct {
	Func     func() ([]byte, error)
	Children map[string]*_bintree_t
}

var _bintree = &_bintree_t{nil, map[string]*_bintree_t{
	"ipsum.txt": &_bintree_t{ipsum_txt, map[string]*_bintree_t{}},
}}
