package resolvers

import (
	"fmt"

	"gitlab.okta-solutions.com/mashroom/backend/common/generic/log"

	"github.com/graphql-go/graphql"
	"gitlab.okta-solutions.com/mashroom/backend/common/graphql/util"
	"gitlab.okta-solutions.com/mashroom/backend/gateway/impl/connections"
	notification "gitlab.okta-solutions.com/mashroom/backend/notification/api"
)

type QuestionRequest struct {
	Email   string `json:"email"`
	Name    string `json:"name"`
	Phone   string `json:"phone"`
	Message string `json:"message"`
}

type QuestionResponse struct {
	Success bool `json:"success"`
}

type message struct {
	params           graphql.ResolveParams
	sendEmailRequest *notification.SendEmailRequest
}

var msg chan message

func initContact(rootQueries, rootMutations *graphql.Fields) {
	msg = make(chan message, 100)
	mutation := graphql.NewObject(graphql.ObjectConfig{
		Name:        "ContactMutation",
		Description: "Contact mutation root",
		Fields: graphql.Fields{
			"question": &graphql.Field{
				Description: "Ask a question to the support",
				Args:        util.BindArguments(QuestionRequest{}),
				Resolve:     ContactMutationQuestionResolver,
				Type:        util.BindOutput(QuestionResponse{}, "Success of sending a question", nil),
			},
		},
	})

	(*rootMutations)["contact"] = &graphql.Field{
		Type: mutation,
		Resolve: func(p graphql.ResolveParams) (interface{}, error) {
			return mutation, nil
		},
	}
	go func() {
		for v := range msg {
			if _, err := connections.NotificationService.SendEmail(v.params.Context, v.sendEmailRequest); err != nil {
				log.WithError(err)
			}
		}
	}()
}

func ContactMutationQuestionResolver(params graphql.ResolveParams) (interface{}, error) {
	request := &QuestionRequest{}
	if err := util.UnmarshalArguments(params.Args, request); err != nil {
		return nil, err
	}

	subject := fmt.Sprintf("New question via contact page from %s", request.Name)
	body := fmt.Sprintf("New question via contact page:<br><br>Name: %s<br>Email: %s<br>Message: %s",
		request.Name, request.Email, request.Message)

	msg <- message{params: params, sendEmailRequest: &notification.SendEmailRequest{
		To:      "support@mashroom.com",
		Subject: subject,
		Body:    body,
		Html:    true,
		ReplyTo: request.Email,
	}}

	respBody := fmt.Sprintf("Hi %s,<br><br>Thank you for your feedback. It is very important to us.<br><br>"+
		"Your message:<br>%s<br><br>This is an automated response. We will reach out to you shortly, as soon as we process your feedback."+
		"<br><br>Kindly let us know if you need any other assistance by emailing us at support@mashroom.com"+
		" or call us on 0113 320 7599.<br><br>Kind Regards,<br>Team mashroom",
		request.Name, request.Message)

	msg <- message{params: params, sendEmailRequest: &notification.SendEmailRequest{
		To:       request.Email,
		Subject:  "Thank you for your feedback. It is very important for us.",
		Body:     respBody,
		Html:     true,
		Template: true,
	}}

	return &QuestionResponse{Success: true}, nil
}
