package resolvers

import (
	"github.com/graphql-go/graphql"
	"gitlab.okta-solutions.com/mashroom/backend/common/graphql/util"
	"gitlab.okta-solutions.com/mashroom/backend/gateway/impl/connections"
	geo "gitlab.okta-solutions.com/mashroom/backend/geo/api"
)

func initGeo(rootQueries, rootMutations *graphql.Fields) {
	points := graphql.NewObject(graphql.ObjectConfig{
		Name: "GetPoints",
		Fields: graphql.Fields{
			"radius": &graphql.Field{
				Description: "Get points within radius",
				Args:        util.BindArguments(geo.GetPointsRadius{}),
				Resolve:     GeoQueryGetPointsRadiusResolver,
				Type:        util.BindOutput(geo.GetPointsResponse{}, "points array", nil),
			},
			"box": &graphql.Field{
				Description: "Get points within box",
				Args:        util.BindArguments(geo.GetPointsBox{}),
				Resolve:     GeoQueryGetPointsBoxResolver,
				Type:        util.BindOutput(geo.GetPointsResponse{}, "points array", nil),
			},
		},
	})

	siteMap := graphql.NewObject(graphql.ObjectConfig{
		Name: "DataSitemap",
		Fields: graphql.Fields{
			"regions": &graphql.Field{
				Description: "Get regions by country",
				Args:        util.BindArguments(geo.GetRegionsSitemapRequest{}),
				Resolve:     GeoQueryGetRegionsSitemapResolver,
				Type:        util.BindOutput(geo.GetRegionsSitemapResponse{}, "regions array", nil),
			},
			"counties": &graphql.Field{
				Description: "Get counties by country and region",
				Args:        util.BindArguments(geo.GetCountiesSitemapRequest{}),
				Resolve:     GeoQueryGetCountiesSitemapResolver,
				Type:        util.BindOutput(geo.GetCountiesSitemapResponse{}, "counties array", nil),
			},
			"towns": &graphql.Field{
				Description: "Get towns by country, region and county",
				Args:        util.BindArguments(geo.GetTownsSitemapRequest{}),
				Resolve:     GeoQueryGetTownsSitemapResolver,
				Type:        util.BindOutput(geo.GetTownsSitemapResponse{}, "towns array", nil),
			},
		},
	})

	towns := graphql.NewObject(graphql.ObjectConfig{
		Name: "GetTowns",
		Fields: graphql.Fields{
			"radius": &graphql.Field{
				Description: "Get towns within radius",
				Args:        util.BindArguments(geo.GetLocalityInRadiusRequest{}),
				Resolve:     GeoQueryGetTownsInRadiusResolver,
				Type:        util.BindOutput(geo.GetTownsResponse{}, "towns array", nil),
			},
			"sub": &graphql.Field{
				Description: "Get towns within current towns or city",
				Args:        util.BindArguments(geo.GetSubTownsRequest{}),
				Resolve:     GeoQueryGetSubTownsResolver,
				Type:        util.BindOutput(geo.GetTownsResponse{}, "towns array", nil),
			},
			"stations": &graphql.Field{
				Description: "Get two stations by type",
				Args:        util.BindArguments(geo.GetStationsRequest{}),
				Resolve:     GeoQueryGetStationsResolver,
				Type:        util.BindOutput(geo.GetStationsResponse{}, "two stations", nil),
			},
			"towns": &graphql.Field{
				Description: "Get towns by query",
				Args:        util.BindArguments(geo.GetTownsRequest{}),
				Resolve:     GeoQueryGetTownsResolver,
				Type:        util.BindOutput(geo.GetTownsResponse{}, "towns array", nil),
			},
			"counties": &graphql.Field{
				Description: "Get counties in region",
				Args:        util.BindArguments(geo.GetCountiesInRegionRequest{}),
				Resolve:     GeoQueryGetCountiesInRegionResolver,
				Type:        util.BindOutput(geo.GetCountiesInRegionResponse{}, "counties array", nil),
			},
		},
	})

	radius := graphql.NewObject(graphql.ObjectConfig{
		Name: "GetPlacesInRadius",
		Fields: graphql.Fields{
			//"towns": &graphql.Field{
			//	Description: "Get towns within radius",
			//	Args:        util.BindArguments(geo.GetLocalityInRadiusRequest{}),
			//	Resolve:     GeoQueryGetTownsInRadiusResolver,
			//	Type:        util.BindOutput(geo.GetTownsResponse{}, "towns array", nil),
			//},
			//"counties": &graphql.Field{
			//	Description: "Get towns within current towns or city",
			//	Args:        util.BindArguments(geo.GetSubTownsRequest{}),
			//	Resolve:     GeoQueryCountiesInRadiusResolver,
			//	Type:        util.BindOutput(geo.GetTownsResponse{}, "towns array", nil),
			//},
			//"regions": &graphql.Field{
			//	Description: "Get two stations by type",
			//	Args:        util.BindArguments(geo.GetStationsRequest{}),
			//	Resolve:     GeoQueryCountiesInRadiusResolver,
			//	Type:        util.BindOutput(geo.GetStationsResponse{}, "two stations", nil),
			//},
			//"stations": &graphql.Field{
			//	Description: "Get two stations by type",
			//	Args:        util.BindArguments(geo.GetStationsRequest{}),
			//	Resolve:     GeoQueryCountiesInRadiusResolver,
			//	Type:        util.BindOutput(geo.GetStationsResponse{}, "two stations", nil),
			//},
			"locality": &graphql.Field{
				Description: "Get towns by query",
				Args:        util.BindArguments(geo.GetLocalityInRadiusRequest{}),
				Resolve:     GeoQueryGetPlacesInRadiusResolver,
				Type:        util.BindOutput(geo.GetLocalityResponse{}, "all places array", nil),
			},
		},
	})

	search := graphql.NewObject(graphql.ObjectConfig{
		Name: "GetPlaces",
		Fields: graphql.Fields{
			"locality": &graphql.Field{
				Description: "Get two stations by type",
				Args:        util.BindArguments(geo.GetLocalityRequest{}),
				Resolve:     GeoQueryGetLocalityResolver,
				Type:        util.BindOutput(geo.GetLocalityResponse{}, "places by query", nil),
			},
		},
	})

	query := graphql.NewObject(graphql.ObjectConfig{
		Name:        "GeoQuery",
		Description: "Geo query root",
		Fields: graphql.Fields{
			"pois": &graphql.Field{
				Description: "Get pois",
				Args:        util.BindArguments(geo.PoiRequest{}),
				Resolve:     GetPoisResolver,
				Type:        util.BindOutput(geo.PoiResponse{}, "Poi array", nil),
			},
			"isochrones": &graphql.Field{
				Description: "Get isochrones",
				Args:        util.BindArguments(geo.IsochroneRequest{}),
				Resolve:     GetIsochronesResolver,
				Type:        util.BindOutput(geo.IsochroneResponse{}, "Isochrones array", nil),
			},
			"points": &graphql.Field{
				Description: "Get raw points",
				Resolve: func(params graphql.ResolveParams) (interface{}, error) {
					return points, nil
				},
				Type: points,
			},
			"towns": &graphql.Field{
				Description: "Get raw towns",
				Resolve: func(params graphql.ResolveParams) (interface{}, error) {
					return towns, nil
				},
				Type: towns,
			},
			"radius": &graphql.Field{
				Description: "Get raw radius",
				Resolve: func(params graphql.ResolveParams) (interface{}, error) {
					return radius, nil
				},
				Type: radius,
			},
			"search": &graphql.Field{
				Description: "Get raw places",
				Resolve: func(params graphql.ResolveParams) (interface{}, error) {
					return search, nil
				},
				Type: search,
			},
			"sitemap": &graphql.Field{
				Description: "Get data for sitemap",
				Resolve: func(params graphql.ResolveParams) (interface{}, error) {
					return siteMap, nil
				},
				Type: siteMap,
			},
		},
	})

	(*rootQueries)["geo"] = &graphql.Field{
		Type: query,
		Resolve: func(p graphql.ResolveParams) (interface{}, error) {
			return query, nil
		},
	}
}

func GetPoisResolver(params graphql.ResolveParams) (interface{}, error) {
	request := &geo.PoiRequest{}
	if err := util.UnmarshalArguments(params.Args, request); err != nil {
		return nil, err
	}
	return connections.GeoService.GetPois(params.Context, request)
}

func GetIsochronesResolver(params graphql.ResolveParams) (interface{}, error) {
	request := &geo.IsochroneRequest{}
	if err := util.UnmarshalArguments(params.Args, request); err != nil {
		return nil, err
	}
	return connections.GeoService.GetIsochrones(params.Context, request)
}

func GeoQueryGetRegionsSitemapResolver(params graphql.ResolveParams) (interface{}, error) {
	request := &geo.GetRegionsSitemapRequest{}
	if err := util.UnmarshalArguments(params.Args, request); err != nil {
		return nil, err
	}
	return connections.GeoService.GetRegionsSitemap(params.Context, request)
}

func GeoQueryGetCountiesSitemapResolver(params graphql.ResolveParams) (interface{}, error) {
	request := &geo.GetCountiesSitemapRequest{}
	if err := util.UnmarshalArguments(params.Args, request); err != nil {
		return nil, err
	}
	return connections.GeoService.GetCountiesSitemap(params.Context, request)
}

func GeoQueryGetTownsSitemapResolver(params graphql.ResolveParams) (interface{}, error) {
	request := &geo.GetTownsSitemapRequest{}
	if err := util.UnmarshalArguments(params.Args, request); err != nil {
		return nil, err
	}
	return connections.GeoService.GetTownsSitemap(params.Context, request)
}

func GeoQueryGetPointsRadiusResolver(params graphql.ResolveParams) (interface{}, error) {
	request := &geo.GetPointsRadius{}
	if err := util.UnmarshalArguments(params.Args, request); err != nil {
		return nil, err
	}
	resp, err := connections.GeoService.GetPoints(params.Context, &geo.GetPointsRequest{
		Method: &geo.GetPointsRequest_Radius{
			Radius: request,
		},
	})
	return resp, err
}

func GeoQueryGetPointsBoxResolver(params graphql.ResolveParams) (interface{}, error) {
	request := &geo.GetPointsBox{}
	if err := util.UnmarshalArguments(params.Args, request); err != nil {
		return nil, err
	}
	return connections.GeoService.GetPoints(params.Context, &geo.GetPointsRequest{
		Method: &geo.GetPointsRequest_Box{
			Box: request,
		},
	})
}

func GeoQueryGetTownsInRadiusResolver(params graphql.ResolveParams) (interface{}, error) {
	request := &geo.GetLocalityInRadiusRequest{}
	if err := util.UnmarshalArguments(params.Args, request); err != nil {
		return nil, err
	}
	return connections.GeoService.GetTownsInRadius(params.Context, request)
}

func GeoQueryGetSubTownsResolver(params graphql.ResolveParams) (interface{}, error) {
	request := &geo.GetSubTownsRequest{}
	if err := util.UnmarshalArguments(params.Args, request); err != nil {
		return nil, err
	}
	return connections.GeoService.GetSubTowns(params.Context, request)
}

func GeoQueryGetStationsResolver(params graphql.ResolveParams) (interface{}, error) {
	request := &geo.GetStationsRequest{}
	if err := util.UnmarshalArguments(params.Args, request); err != nil {
		return nil, err
	}
	return connections.GeoService.GetStations(params.Context, request)
}

func GeoQueryGetTownsResolver(params graphql.ResolveParams) (interface{}, error) {
	request := &geo.GetTownsRequest{}
	if err := util.UnmarshalArguments(params.Args, request); err != nil {
		return nil, err
	}
	return connections.GeoService.GetTowns(params.Context, request)
}

func GeoQueryGetLocalityResolver(params graphql.ResolveParams) (interface{}, error) {
	request := &geo.GetLocalityRequest{}
	if err := util.UnmarshalArguments(params.Args, request); err != nil {
		return nil, err
	}
	return connections.GeoService.GetPlacesByQuery(params.Context, request)
}

func GeoQueryGetPlacesInRadiusResolver(params graphql.ResolveParams) (interface{}, error) {
	request := &geo.GetLocalityInRadiusRequest{}
	if err := util.UnmarshalArguments(params.Args, request); err != nil {
		return nil, err
	}
	return connections.GeoService.GetPlacesInRadius(params.Context, request)
}

func GeoQueryGetCountiesInRegionResolver(params graphql.ResolveParams) (interface{}, error) {
	request := &geo.GetCountiesInRegionRequest{}
	if err := util.UnmarshalArguments(params.Args, request); err != nil {
		return nil, err
	}
	return connections.GeoService.GetCountiesInRegion(params.Context, request)
}
