package rest

import (
	"context"
	"crypto/sha256"
	"net/http"
	"strings"

	"gitlab.okta-solutions.com/mashroom/backend/common/generic/log"
	"gitlab.okta-solutions.com/mashroom/backend/gateway/impl/connections"
	signature "gitlab.okta-solutions.com/mashroom/backend/signature/api"
)

// Callback from Hellosign API

const (
	MultipartMemoryBuffer = (1 << 20) * 128
)

func HellosignHandler(req *http.Request) (int, string, error) {
	err := req.ParseMultipartForm(MultipartMemoryBuffer)
	if err != nil {
		return Err500Result(err)
	}

	jsonList, ok := req.MultipartForm.Value["json"]
	if !ok {
		return Err500Result(err)
	}
	jsonStr := strings.Join(jsonList, "")

	log.Info(jsonStr)

	data := []byte(jsonStr)

	actual := sha256.New().Sum(data)

	stream, err := connections.SignatureService.HandleCallback(context.Background())
	if err != nil {
		return Err500Result(err)
	}

	err = stream.Send(&signature.HandleCallbackEvent{
		Init: &signature.HandleCallbackInit{
			Sha256: actual,
		},
	})
	if err != nil {
		return Err500Result(err)
	}

	for len(data) > 0 {
		var trans []byte
		if len(data) > signature.ChunkSize {
			trans = data[:signature.ChunkSize]
			data = data[signature.ChunkSize:]
		} else {
			trans = data
			data = nil
		}
		err = stream.Send(&signature.HandleCallbackEvent{
			Chunk: &signature.DataChunk{
				Data: trans,
			},
		})

		if err != nil {
			return Err500Result(err)
		}
	}

	err = stream.CloseSend()
	if err != nil {
		return Err500Result(err)
	}

	return http.StatusOK, "Hello API Event Received", nil // required by hellosign protocol
}
