package rest

import (
	"context"
	"crypto/sha256"
	"net/http"
	"strings"

	cardpayment "gitlab.okta-solutions.com/mashroom/backend/cardpayment/api"
	"gitlab.okta-solutions.com/mashroom/backend/common/generic/log"
	"gitlab.okta-solutions.com/mashroom/backend/gateway/impl/connections"
	signature "gitlab.okta-solutions.com/mashroom/backend/signature/api"
)

func StripeHandler(req *http.Request) (int, string, error) {
	err := req.ParseMultipartForm(MultipartMemoryBuffer)
	if err != nil {
		return Err500Result(err)
	}

	jsonList, ok := req.MultipartForm.Value["json"]
	if !ok {
		return Err500Result(err)
	}
	jsonStr := strings.Join(jsonList, "")

	log.Info(jsonStr)

	data := []byte(jsonStr)

	actual := sha256.New().Sum(data)

	stream, err := connections.CardPaymentService.HandleCallback(context.Background())
	if err != nil {
		return Err500Result(err)
	}

	err = stream.Send(&cardpayment.HandleCallbackRequest{
		Init: &cardpayment.HandleCallbackInit{
			Sha256: actual,
		},
	})
	if err != nil {
		return Err500Result(err)
	}

	for len(data) > 0 {
		var trans []byte
		if len(data) > signature.ChunkSize {
			trans = data[:signature.ChunkSize]
			data = data[signature.ChunkSize:]
		} else {
			trans = data
			data = nil
		}
		err = stream.Send(&cardpayment.HandleCallbackRequest{
			Chunk: &cardpayment.DataChunk{
				Data: trans,
			},
		})

		if err != nil {
			return Err500Result(err)
		}
	}

	err = stream.CloseSend()
	if err != nil {
		return Err500Result(err)
	}

	return http.StatusOK, "", nil
}
